@@ -91,7 +91,7 @@ class Tuple(dc.Formula):
 
     @typechecked
     def contains_variable(self, variable: dc.Variable) -> bool:
-        return any(var == variable for var in self.variables)
+        return variable in self.variables
 
     @typechecked
     def contains_variable_typing(self, variable: dc.Variable) -> bool:
